@@ -1,6 +1,15 @@
+from __future__ import annotations
+
 import asyncio
 import functools
 from asyncio import AbstractEventLoop
+from typing import TypeVar
+
+T = TypeVar("T")
+
+
+def unpack_list(value: list[T], size: int) -> list[T | None]:
+    return (value + [None] * size)[:size]
 
 
 def get_running_loop_or_create_one() -> AbstractEventLoop:
@@ -12,19 +21,6 @@ def get_running_loop_or_create_one() -> AbstractEventLoop:
     return loop
 
 
-def run_in_executor():
-    loop = get_running_loop_or_create_one()
-
-    def decorator(func):
-        @functools.wraps(func)
-        def wrapped(*args, **kwargs):
-            return asyncio.run_coroutine_threadsafe(coro=func(*args, **kwargs), loop=loop)
-
-        return wrapped
-
-    return decorator
-
-
 def run_sync():
     loop = get_running_loop_or_create_one()
 
